clear all; close all; clc;

addpath('HeN2')
load neededParameterForBenchmarking.mat
load speciesDensities.mat
speciesNum_pure = speciesNum;
specisName_pure = species{1}';
n_pure = n_density(end,1:end);

addpath('HeN2_impurity')
load neededParameterForBenchmarking.mat
speciesNum_impurity = speciesNum;
specisName_impurity = species{1}';
%%%%%%%%%%%%%%%%%%%%%%%%%%%
% index of "the pure species" in impurity
impurityPure_index_He = 1:5;
impurityPure_index_e = 6;
impurityPure_index_N2 = 7:15;
impurityPure_index_N2v = 42:98;
%%%%%%%%%%%%%%%%%%%%%%%%%%%

load calculationOfMineForBenchmarking_impurity.mat
impurity = mine_reset_air;
% pick out the pure species from impurity species, and make as the same
% order of pure species.
n_impurityPure = zeros(length(mine_n_list),speciesNum_pure+1);
for i=1:length(mine_n_list)
    n_impurityPure(i,:) = [mine_n_list{i}(end,impurityPure_index_He)...
                           , mine_n_list{i}(end,impurityPure_index_e)...
                           , mine_n_list{i}(end,impurityPure_index_N2)...
                           , mine_n_list{i}(end,impurityPure_index_N2v)...
                           , mine_n_list{i}(end,end)];
end

impurity_ppm = [0 impurity]*1e6;
n = [n_pure; n_impurityPure];



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
norm = (n./n(1,:).*100)';
overAll = [[specisName_pure'; "Energy"], num2cell(norm)]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(13)

norm_e = norm(6,:);
norm_Te = (n(:,73)./n(:,6)./1.5)./(n(1,73)/n(1,6)/1.5).*100

norm_HeNNeu = [norm(2,:); norm(4,:); norm(7:8,:); norm(11:12,:); norm_e; norm_Te'];
norm_HeNNeu = norm_HeNNeu(:,2:end)-norm_HeNNeu(:,1); 

name = [{'He(2^3S)'} {'He_2^*'} {'N(^4S)'} {'N(^2D)'} {'N_2(A^3\Sigma)'} {'N_2(B^3\Pi)'} {'e'} {'T_e'}];
x_categorical = categorical(name);
x_categorical = reordercats(x_categorical,{'He(2^3S)' 'He_2^*' 'N(^4S)' 'N(^2D)' 'N_2(A^3\Sigma)' 'N_2(B^3\Pi)' 'e' 'T_e'});

barWidth = 1;
hb = bar(x_categorical,norm_HeNNeu,'BarWidth', barWidth);

xtickangle(90)

ylim([-63 8.5])
yticks([-60:15:0])
ylabel('Relative variation (%)')
set(gca,'FontSize',20);

hb(1).FaceColor = [0 0 0;];
hb(2).FaceColor = [0.45 0.45 0.45;];
hb(3).FaceColor = [0.95 0.95 0.95;];
% hb(1).FaceColor = [1 0 0;];
% hb(2).FaceColor = [0 0 1;];
% hb(3).FaceColor = [0 1 0;];
% hb(4).FaceColor = [0.5 0.5 0.5;];
lgd = legend('1 ppm', '10 ppm', '100 ppm','Location', 'southeast');
lgd.FontSize = 20;
text(0.05,0.95,'(c)','Units','normalized','Color','k','FontSize',20)

set(gcf,'position',[100,100,600,500])

% saveas(figure(13),'/home/he/Pictures/paper/13c_HeN2_impurity.jpg');
% saveas(figure(13),'/home/he/Pictures/paper/13c_HeN2_impurity.png');
% saveas(figure(13),'/home/he/Pictures/paper/13c_HeN2_impurity.eps', 'epsc');
% saveas(figure(13),'/home/he/Pictures/paper/13c_HeN2_impurity.pdf');



